@@ -69,9 +69,6 @@ static gchar 	*get_dirname_from_uri 		(const char          *uri);
 static gboolean  gedit_file_save_as_real 	(const gchar         *file_name, 
 						 const GeditEncoding *encoding,
 						 GeditMDIChild       *child);
-static gboolean	 gedit_file_open_uri_list_real 	(GSList              *uri_list, 
-						 const GeditEncoding *encoding, 
-						 gboolean             create);
 static void	 open_files 			(void);
 static void	 show_progress_bar 		(gchar               *uri, 
 						 gboolean             show, 
@@ -147,7 +144,6 @@ gedit_file_new (void)
 void 
 gedit_file_close (GtkWidget *view)
 {
-	gint ret;
 	BonoboMDIChild* child;
 
 	gedit_debug (DEBUG_FILE, "");
@@ -159,18 +155,19 @@ gedit_file_close (GtkWidget *view)
 
 	if (g_list_length (bonobo_mdi_child_get_views (child)) > 1)
 	{		
-		ret = bonobo_mdi_remove_view (BONOBO_MDI (gedit_mdi), view, FALSE);
+		bonobo_mdi_remove_view (BONOBO_MDI (gedit_mdi), view, FALSE);
 		gedit_debug (DEBUG_COMMANDS, "View removed.");
 	}
 	else
 	{
-		ret = bonobo_mdi_remove_child (BONOBO_MDI (gedit_mdi), child, FALSE);
+		bonobo_mdi_remove_child (BONOBO_MDI (gedit_mdi), child, FALSE);
 		gedit_debug (DEBUG_COMMANDS, "Child removed.");
 	}
 
+	gedit_mdi_set_active_window_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
+
 	if (bonobo_mdi_get_active_child (BONOBO_MDI (gedit_mdi)) == NULL)
 	{
-		gedit_mdi_set_active_window_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
 		gedit_mdi_clear_active_window_statusbar (gedit_mdi);
 	}
 
@@ -217,7 +214,7 @@ gedit_file_open (GeditMDIChild *active_child)
 			default_path,
 			&encoding);
 
-	gedit_file_open_uri_list_real (files, encoding, TRUE);
+	gedit_file_open_uri_list (files, encoding, 0, TRUE);
 
 	g_slist_free (files);
 	g_free (default_path);
@@ -338,8 +335,8 @@ gedit_file_save_as (GeditMDIChild *child)
 	GeditDocument *doc;
 	GtkWidget *view;
 	gchar *fname = NULL;
+	gchar *untitled_name = NULL;
 	gchar *path = NULL;
-	gchar *raw_uri = NULL;
 	const GeditEncoding *encoding;
 
 	gedit_debug (DEBUG_FILE, "");
@@ -361,37 +358,42 @@ gedit_file_save_as (GeditMDIChild *child)
 		bonobo_mdi_set_active_view (BONOBO_MDI (gedit_mdi), view);
 	}
 	
-	raw_uri = gedit_document_get_raw_uri (doc);
-
 	if (gedit_document_is_untitled (doc))
 	{
-		char *tmpstr;
-		
 		path = (gedit_default_path != NULL) ? 
 			g_strdup (gedit_default_path) : NULL;
 
-		tmpstr = gedit_document_get_uri (doc);
-		fname = g_filename_from_utf8 (tmpstr, -1, NULL, NULL, NULL);
-		if (!fname)
-			/* FIXME: should fname remain NULL in this case? - Paolo */		
-			fname = g_strdup ("Untitled"); /* Use ASCII */
-		g_free (tmpstr);
+		untitled_name = gedit_document_get_uri (doc);
+		if (untitled_name == NULL)
+			untitled_name = g_strdup ("Untitled"); /* Use ASCII */
+
+		g_return_val_if_fail (untitled_name != NULL, FALSE);
 	}
 	else
 	{
+		gchar *raw_uri = gedit_document_get_raw_uri (doc);
+
 		g_return_val_if_fail (raw_uri != NULL, FALSE);
 
-		fname = eel_uri_get_basename (raw_uri);
-
 		if (gedit_utils_uri_has_file_scheme (raw_uri))
+		{
+			fname = eel_uri_get_basename (raw_uri);
+			g_return_val_if_fail (fname != NULL, FALSE);
+
 			path = get_dirname_from_uri (raw_uri);
+		}
 		else
+		{
+			untitled_name = gedit_document_get_short_name (doc);
+			g_return_val_if_fail (untitled_name != NULL, FALSE);
+
 			path = (gedit_default_path != NULL) ? 
 				g_strdup (gedit_default_path) : NULL;
+		}
+
+		g_free (raw_uri);
 	}
-				
-	g_return_val_if_fail (fname != NULL, FALSE);
-	
+
 	encoding = gedit_document_get_encoding (doc);
 
 	file = gedit_file_selector_save (
@@ -400,13 +402,12 @@ gedit_file_save_as (GeditMDIChild *child)
 		        _("Save as..."), 
 			path,
 			fname,
+			untitled_name,
 			&encoding);
 	
-	g_free (raw_uri);
 	g_free (fname);
-	
-	if (path != NULL)
-		g_free (path);
+	g_free (untitled_name);
+	g_free (path);
 
 	if (file != NULL) 
 	{
@@ -515,9 +516,10 @@ gedit_file_close_all (void)
 
 	ret = gedit_mdi_remove_all (gedit_mdi);
 
+	gedit_mdi_set_active_window_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
+
 	if (bonobo_mdi_get_active_child (BONOBO_MDI (gedit_mdi)) == NULL)
 	{
-		gedit_mdi_set_active_window_verbs_sensitivity (BONOBO_MDI (gedit_mdi));
 		gedit_mdi_clear_active_window_statusbar (gedit_mdi); 
 	}
 
@@ -590,6 +592,7 @@ static gboolean
 gedit_file_revert_dialog (GeditDocument *doc)
 {
 	GtkWidget *msgbox;
+	AtkObject *obj;
 	gint ret;
 	gchar *name;
 	gchar *primary_msg;
@@ -607,24 +610,24 @@ gedit_file_revert_dialog (GeditDocument *doc)
 	{
 		secondary_msg = g_strdup_printf (
 					ngettext ("Changes made to the document in the last %ld second "
-					    	  "will be definitively lost.",
+					    	  "will be permanently lost.",
 						  "Changes made to the document in the last %ld seconds "
-					    	  "will be definitively lost.",
+					    	  "will be permanently lost.",
 						  seconds),
 					seconds);
 	}
 	else if (seconds < 75) /* 55 <= seconds < 75 */
 	{
 		secondary_msg = g_strdup (_("Changes made to the document in the last minute "
-					    "will be definitively lost."));
+					    "will be permanently lost."));
 	}
 	else if (seconds < 110) /* 75 <= seconds < 110 */
 	{
 		secondary_msg = g_strdup_printf (
 					ngettext ("Changes made to the document in the last minute and "
-						  "%ld second will be definitively lost.",
+						  "%ld second will be permanently lost.",
 						  "Changes made to the document in the last minute and "
-						  "%ld seconds will be definitively lost.",
+						  "%ld seconds will be permanently lost.",
 						  seconds - 60 ),
 					seconds - 60);
 	}
@@ -632,9 +635,9 @@ gedit_file_revert_dialog (GeditDocument *doc)
 	{
 		secondary_msg = g_strdup_printf (
 					ngettext ("Changes made to the document in the last %ld minute "
-					    	  "will be definitively lost.",
+					    	  "will be permanently lost.",
 						  "Changes made to the document in the last %ld minutes "
-					    	  "will be definitively lost.",
+					    	  "will be permanently lost.",
 						  seconds / 60),
 					seconds / 60);
 	}
@@ -647,15 +650,15 @@ gedit_file_revert_dialog (GeditDocument *doc)
 		if (minutes < 5)
 		{
 			secondary_msg = g_strdup (_("Changes made to the document in the last hour "
-						    "will be definitively lost."));
+						    "will be permanently lost."));
 		}
 		else
 		{
 			secondary_msg = g_strdup_printf (
 					ngettext ("Changes made to the document in the last hour and "
-						  "%d minute will be definitively lost.",
+						  "%d minute will be permanently lost.",
 						  "Changes made to the document in the last hour and "
-						  "%d minutes will be definitively lost.",
+						  "%d minutes will be permanently lost.",
 						  minutes),
 					minutes);
 		}
@@ -668,9 +671,9 @@ gedit_file_revert_dialog (GeditDocument *doc)
 
 		secondary_msg = g_strdup_printf (
 					ngettext ("Changes made to the document in the last %d hour "
-					    	  "will be definitively lost.",
+					    	  "will be permanently lost.",
 						  "Changes made to the document in the last %d hours "
-					    	  "will be definitively lost.",
+					    	  "will be permanently lost.",
 						  hours),
 					hours);
 	}
@@ -694,6 +697,10 @@ gedit_file_revert_dialog (GeditDocument *doc)
 
 	gtk_dialog_set_default_response	(GTK_DIALOG (msgbox), GTK_RESPONSE_CANCEL);
 
+	obj = gtk_widget_get_accessible (msgbox);
+	if (GTK_IS_ACCESSIBLE (obj))
+		atk_object_set_name (obj, _("Question"));
+
 	gtk_window_set_resizable (GTK_WINDOW (msgbox), FALSE);
 
 	ret = gtk_dialog_run (GTK_DIALOG (msgbox));
@@ -789,14 +796,6 @@ gedit_file_revert (GeditMDIChild *child)
 	gedit_document_revert (doc);
 }
 
-gboolean 
-gedit_file_open_uri_list (GSList* uri_list, gint l, gboolean create)
-{
-	line = l;
-	
-	return gedit_file_open_uri_list_real (uri_list, NULL, create);
-}
-
 gboolean 
 gedit_file_open_recent (EggRecentView *view, EggRecentItem *item, gpointer data)
 {
@@ -853,12 +852,12 @@ gedit_file_open_single_uri (const gchar* uri, const GeditEncoding *encoding)
 	
 	if (uri == NULL) 
 		return FALSE;
-	
+
 	full_path = eel_make_uri_from_input (uri);
 
 	uri_list = g_slist_prepend (NULL, full_path);
 	
-	gedit_file_open_uri_list_real (uri_list, encoding, FALSE);
+	gedit_file_open_uri_list (uri_list, encoding, 0, FALSE);
 
 	return TRUE;
 }
@@ -942,47 +941,22 @@ gedit_file_open_from_stdin (GeditMDIChild *active_child)
 }
 
 
-static gboolean
+static void 
 create_new_file (const gchar *uri)
 {
-	GtkWidget *dialog;
-	gboolean   created;
-	gchar     *formatted_uri;
+	gint ret;
+	GeditMDIChild *new_child;
 
-	formatted_uri = gnome_vfs_format_uri_for_display (uri);
-	g_return_val_if_fail (formatted_uri != NULL, FALSE);
-			
-	created = FALSE;
+	new_child = gedit_mdi_child_new_with_uri (uri, NULL);
+	ret = bonobo_mdi_add_child (BONOBO_MDI (gedit_mdi), BONOBO_MDI_CHILD (new_child));
+	g_return_if_fail (ret != FALSE);
+	gedit_debug (DEBUG_COMMANDS, "Child added.");
 
-	/* FIXME: Is it conforming to GNOME HIG ? - Paolo (Jan 02, 2004) */	
-	dialog = gtk_message_dialog_new (GTK_WINDOW (gedit_get_active_window ()),
-					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_QUESTION,
-					 GTK_BUTTONS_YES_NO,
-					 _("The file \"%s\" does not exist. Would you like to create it?"),
-					 formatted_uri);
+	ret = bonobo_mdi_add_view (BONOBO_MDI (gedit_mdi), BONOBO_MDI_CHILD (new_child));
+	g_return_if_fail (ret != FALSE);
+	gedit_debug (DEBUG_COMMANDS, "View added.");
 
-	g_free (formatted_uri);
-
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_NO);
-
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
-	{
-		created = gedit_utils_create_empty_file (uri);
-
-		if (!created)
-		{
-			gedit_utils_error_reporting_creating_file (uri, 
-								   errno, 
-								   GTK_WINDOW (dialog));
-		}
-	}
-									
-	gtk_widget_destroy (dialog);
-
-	return created;
+	gtk_widget_grab_focus (GTK_WIDGET (gedit_get_active_view ()));
 }
 
 static gboolean
@@ -1160,7 +1134,6 @@ set_progress_bar (gulong size, gulong total_size)
 	}
 }
 
-
 static void 
 document_loading_cb (GeditDocument *document,
 		     gulong         size,
@@ -1466,8 +1439,11 @@ open_files ()
 }
 
 /* Note that all the uris will be opened with the same encoding */
-static gboolean
-gedit_file_open_uri_list_real (GSList *uri_list, const GeditEncoding *encoding, gboolean create)
+gboolean
+gedit_file_open_uri_list (GSList *uri_list,
+			  const GeditEncoding *encoding,
+			  gint line_pos,
+			  gboolean create)
 {
 	gedit_debug (DEBUG_FILE, "");
 	
@@ -1511,10 +1487,7 @@ gedit_file_open_uri_list_real (GSList *uri_list, const GeditEncoding *encoding,
 			{
 				if (create)
 				{
-					if (create_new_file (uri))
-					{
-						uris_to_open = g_slist_prepend (uris_to_open, uri);
-					}
+					create_new_file (uri);
 				}
 				else
 				{
@@ -1541,7 +1514,8 @@ gedit_file_open_uri_list_real (GSList *uri_list, const GeditEncoding *encoding,
 		}
 
 		encoding_to_use = encoding;
-		
+		line = line_pos > 0 ? line_pos : 0;
+
 		gedit_mdi_set_state (gedit_mdi, GEDIT_STATE_LOADING);
 		
 		open_files ();
