@@ -36,6 +36,7 @@
 #include <glib/gunicode.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomevfs/gnome-vfs.h>
+#include <eel/eel-gtk-extensions.h>
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-string.h>
 
@@ -170,7 +171,7 @@ bonobo_window_flash (BonoboWindow * win, const gchar * flash)
  * Flash a temporary message on the statusbar of gedit.
  **/
 void
-gedit_utils_flash (gchar *msg)
+gedit_utils_flash (const gchar *msg)
 {
 	g_return_if_fail (msg != NULL);
 	
@@ -197,6 +198,49 @@ gedit_utils_flash_va (gchar *format, ...)
 	g_free (msg);
 }
 
+void
+gedit_utils_set_status (const gchar *msg)
+{
+	BonoboWindow *win;
+	BonoboUIComponent *ui_component;
+
+	win = gedit_get_active_window ();
+  	g_return_if_fail (BONOBO_IS_WINDOW (win));
+  	
+	ui_component = bonobo_mdi_get_ui_component_from_window (win);
+	g_return_if_fail (ui_component != NULL);
+	
+	if (current_mi != NULL)
+	{
+		g_source_remove (current_mi->timeoutid);
+		remove_message_timeout (current_mi);
+	}
+	
+	if (bonobo_ui_component_path_exists (ui_component, "/status", NULL))
+	{
+		bonobo_ui_component_set_status (ui_component, (msg != NULL) ? msg : " ", NULL);
+    		
+		current_mi =  NULL;
+  	}   
+}
+
+void
+gedit_utils_set_status_va (gchar *format, ...)
+{
+	va_list args;
+	gchar *msg;
+
+	g_return_if_fail (format != NULL);
+
+	va_start (args, format);
+	msg = g_strdup_vprintf (format, args);
+	va_end (args);
+
+	gedit_utils_set_status (msg);
+	g_free (msg);
+}
+
+
 gboolean
 gedit_utils_uri_has_file_scheme (const gchar *uri)
 {
@@ -250,54 +294,6 @@ gedit_utils_is_uri_read_only (const gchar* uri)
 	return res;	
 }
 
-GtkWidget* 
-gedit_button_new_with_stock_image (const gchar* text, const gchar* stock_id)
-{
-	GtkWidget *button;
-	GtkStockItem item;
-	GtkWidget *label;
-	GtkWidget *image;
-	GtkWidget *hbox;
-	GtkWidget *align;
-
-	button = gtk_button_new ();
-
- 	if (GTK_BIN (button)->child)
-    		gtk_container_remove (GTK_CONTAINER (button),
-				      GTK_BIN (button)->child);
-
-  	if (gtk_stock_lookup (stock_id, &item))
-    	{
-      		label = gtk_label_new_with_mnemonic (text);
-
-		gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
-      
-		image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-      		hbox = gtk_hbox_new (FALSE, 2);
-
-      		align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-      
-      		gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-      		gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-      
-      		gtk_container_add (GTK_CONTAINER (button), align);
-      		gtk_container_add (GTK_CONTAINER (align), hbox);
-      		gtk_widget_show_all (align);
-
-      		return button;
-    	}
-
-      	label = gtk_label_new_with_mnemonic (text);
-      	gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
-  
-  	gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
-
-  	gtk_widget_show (label);
-  	gtk_container_add (GTK_CONTAINER (button), label);
-
-	return button;
-}
-
 GtkWidget*
 gedit_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* stock_id,
 			 gint response_id)
@@ -308,7 +304,7 @@ gedit_dialog_add_button (GtkDialog *dialog, const gchar* text, const gchar* stoc
 	g_return_val_if_fail (text != NULL, NULL);
 	g_return_val_if_fail (stock_id != NULL, NULL);
 
-	button = gedit_button_new_with_stock_image (text, stock_id);
+	button = eel_gtk_button_new_with_stock_icon (text, stock_id);
 	g_return_val_if_fail (button != NULL, NULL);
 
 	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
@@ -386,7 +382,6 @@ gedit_utils_error_reporting_loading_file (
 	GtkWidget *dialog;
 
 	g_return_if_fail (uri != NULL);
-	g_return_if_fail (error != NULL);
 	
 	full_formatted_uri = eel_format_uri_for_display (uri);
 
@@ -403,7 +398,7 @@ gedit_utils_error_reporting_loading_file (
 	else
 		encoding_name = g_strdup ("UTF-8");
 	
-	if (error->domain == GEDIT_DOCUMENT_IO_ERROR)
+	if ((error != NULL) && (error->domain == GEDIT_DOCUMENT_IO_ERROR))
 	{
 		switch (error->code)
 		{
@@ -564,6 +559,11 @@ gedit_utils_error_reporting_loading_file (
 
 				break;
 
+			case GNOME_VFS_ERROR_GENERIC:
+				error_message = g_strdup_printf (
+                        			_("Could not open the file \"%s\"."),
+					 	uri_for_display);
+				break;
 			/*
 			case GNOME_VFS_ERROR_GENERIC:
 			case GNOME_VFS_ERROR_INTERNAL:
@@ -657,13 +657,13 @@ gedit_utils_error_reporting_loading_file (
 	
 	if (error_message == NULL)
 	{
-		if (error->message == NULL)
+		if ((error == NULL) || (error->message == NULL))
 			error_message = g_strdup_printf (
                         			_("Could not open the file \"%s\"."),
 					 	uri_for_display);
 		else
 			error_message = g_strdup_printf (
-                        			_("Could not open the file \"%s\".\n\n%s"),
+                        			_("Could not open the file \"%s\".\n\n%s."),
 					 	uri_for_display, error->message);
 
 	}
@@ -743,7 +743,7 @@ gedit_utils_error_reporting_saving_file (
 void
 gedit_utils_error_reporting_reverting_file (
 		const gchar *uri,
-		GError *error,
+		const GError *error,
 		GtkWindow *parent)
 {
 	gchar *scheme_string;
@@ -758,7 +758,7 @@ gedit_utils_error_reporting_reverting_file (
 	g_return_if_fail (uri != NULL);
 	g_return_if_fail (error != NULL);
 	
-	full_formatted_uri = eel_format_uri_for_display (uri);
+	full_formatted_uri = gnome_vfs_format_uri_for_display (uri);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
@@ -1154,12 +1154,16 @@ gedit_utils_convert_search_text (const gchar *text)
 	cur = text;
 	end = text + length;
 	prev = NULL;
-	while (cur != end) {
+	
+	while (cur != end) 
+	{
 		const gchar *next;
 		next = g_utf8_next_char (cur);
 
-		if (prev && (*prev == '\\')) {
-			switch (*cur) {
+		if (prev && (*prev == '\\')) 
+		{
+			switch (*cur) 
+			{
 				case 'n':
 					str = g_string_append (str, "\n");
 				break;
@@ -1175,16 +1179,25 @@ gedit_utils_convert_search_text (const gchar *text)
 				break;
 				default:
 					str = g_string_append (str, "\\");
-					str = g_string_append (str, cur);
+					str = g_string_append_len (str, cur, next - cur);
 				break;
 			}
-		} else if (*cur != '\\') {
+		} 
+		else if (*cur != '\\') 
+		{
 			str = g_string_append_len (str, cur, next - cur);
+		} 
+		else if ((next == end) && (*cur == '\\')) 
+		{
+			str = g_string_append (str, "\\");
 		}
-
+		
 		if (!drop_prev)
+		{
 			prev = cur;
-		else {
+		}
+		else 
+		{
 			prev = NULL;
 			drop_prev = FALSE;
 		}
@@ -1195,47 +1208,6 @@ gedit_utils_convert_search_text (const gchar *text)
 	return g_string_free (str, FALSE);
 }
 
-gboolean
-gedit_utils_create_empty_file (const gchar *uri)
-{
-	gchar *canonical_uri;
-	gchar *filename;
-	int fd;
-	
-	g_return_val_if_fail (uri != NULL, FALSE);
-	
-	/* Get filename from uri */
-	if (!gedit_utils_uri_has_file_scheme (uri))
-		return FALSE;
-			
-	canonical_uri = eel_make_uri_canonical (uri);
-	g_return_val_if_fail (canonical_uri != NULL, FALSE);
-	
-	gedit_debug (DEBUG_FILE, "CANONICAL URI: %s", canonical_uri);
-
-	filename = gnome_vfs_get_local_path_from_uri (canonical_uri);
-	g_free (canonical_uri);
-	
-	if (filename == NULL)
-	{
-		gedit_debug (DEBUG_FILE, "FILENAME: NULL");
-
-		return FALSE;
-	}
-	
-	fd = open (filename, O_CREAT | O_EXCL | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
-
-	g_free (filename);
-	
-	if (fd == -1)
-		return FALSE;
-	
-	return (close (fd) == 0);
-}
-
-
-
-
 #define GEDIT_STDIN_BUFSIZE 1024
 
 gchar *
@@ -1285,10 +1257,18 @@ gedit_utils_get_stdin (void)
 }
 
 void 
-gedit_warning (gchar *str, GtkWindow *parent)
+gedit_warning (GtkWindow *parent, gchar *format, ...)
 {
+	va_list args;
+	gchar *str;
 	GtkWidget *dialog;
 
+	g_return_if_fail (format != NULL);
+
+	va_start (args, format);
+	str = g_strdup_vprintf (format, args);
+	va_end (args);
+
 	dialog = gtk_message_dialog_new (
 			parent,
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -1299,10 +1279,12 @@ gedit_warning (gchar *str, GtkWindow *parent)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
 	gtk_dialog_run (GTK_DIALOG (dialog));
 
 	gtk_widget_destroy (dialog);
+
+	g_free (str);
 }
 
-
